@@ -47,7 +47,11 @@ impl From<&Options> for Meilisearch {
 
 impl Meilisearch {
     pub fn r#async(self, r#async: bool) -> Self {
-        Self { r#async, ..self }
+        // we stay in async mode if the command is being piped
+        Self {
+            r#async: r#async || atty::isnt(atty::Stream::Stdout),
+            ..self
+        }
     }
 
     pub fn get(&self, url: impl AsRef<str>) -> RequestBuilder {
@@ -220,7 +224,7 @@ impl Meilisearch {
     }
 
     pub fn get_index(&self, index: Option<String>) -> Result<()> {
-        let index = index.unwrap_or(self.index.to_string());
+        let index = index.unwrap_or_else(|| self.index.to_string());
         let response = self
             .get(format!("{}/indexes/{}", self.addr, index))
             .send()?;
@@ -228,7 +232,7 @@ impl Meilisearch {
     }
 
     pub fn create_index(&self, index: Option<String>, primary_key: Option<String>) -> Result<()> {
-        let index = index.unwrap_or(self.index.to_string());
+        let index = index.unwrap_or_else(|| self.index.to_string());
         let mut body = json!({ "uid": index });
         if let Some(primary_key) = primary_key {
             body["primaryKey"] = json!(primary_key);
@@ -241,7 +245,7 @@ impl Meilisearch {
     }
 
     pub fn update_index(&self, index: Option<String>, primary_key: Option<String>) -> Result<()> {
-        let index = index.unwrap_or(self.index.to_string());
+        let index = index.unwrap_or_else(|| self.index.to_string());
         let mut body = json!({});
         if let Some(primary_key) = primary_key {
             body["primaryKey"] = json!(primary_key);
@@ -254,7 +258,7 @@ impl Meilisearch {
     }
 
     pub fn delete_index(&self, index: Option<String>) -> Result<()> {
-        let index = index.unwrap_or(self.index.to_string());
+        let index = index.unwrap_or_else(|| self.index.to_string());
         let response = self
             .delete(format!("{}/indexes/{}", self.addr, index))
             .send()?;
