@@ -63,6 +63,9 @@ pub enum Command {
         /// The command will exit immediatly after sending the documents
         #[structopt(long)]
         r#async: bool,
+        /// The primary key
+        #[structopt(short, long)]
+        primary: Option<String>,
         /// The file you want to send
         file: Option<PathBuf>,
     },
@@ -75,6 +78,9 @@ pub enum Command {
         /// The command will exit immediatly after sending the documents
         #[structopt(long)]
         r#async: bool,
+        /// The primary key
+        #[structopt(short, long)]
+        primary: Option<String>,
         /// The file you want to send
         file: Option<PathBuf>,
     },
@@ -102,19 +108,26 @@ pub enum Command {
         #[structopt(short, long)]
         watch: bool,
     },
-    /// Get information about the tasks.
+    /// Get information about the task of an index.
+    #[structopt(aliases = &["tasks"])]
     Task {
         /// The task you want to inspect.
         task_id: Option<TaskId>,
         /// If the flag is set, the command will wait until the update finishes
         #[structopt(short, long)]
         watch: bool,
+
+        /// If the flag is set, the command will look in all the tasks instead of the tasks by indexes.
+        #[structopt(long)]
+        all: bool,
     },
     /// Do an healthcheck
     Health,
     /// Return the version of the running meilisearch instance
+    #[structopt(aliases = &["ver"])]
     Version,
     /// Return the stats about the indexes
+    #[structopt(aliases = &["stat"])]
     Stats,
     /// Do a search. You can pipe your parameter in the command as a json.
     /// Or you can specify directly what you want to search in the arguments.
@@ -129,16 +142,21 @@ pub enum Command {
     },
     /// Get or update the settings.
     /// You can pipe your settings in the command.
+    #[structopt(aliases = &["set", "setting"])]
     Settings {
         /// The command will exit immediatly after sending the new settings
         #[structopt(long)]
         r#async: bool,
     },
     /// Manipulate indexes, add `--help` to see all the subcommands.
+    #[structopt(aliases = &["indexes"])]
     Index {
         #[structopt(subcommand)]
         command: IndexesCommand,
     },
+    /// Get the keys
+    #[structopt(aliases = &["keys"])]
+    Key,
 }
 
 #[derive(Debug, StructOpt)]
@@ -159,6 +177,9 @@ pub enum IndexesCommand {
         /// Primary key
         #[structopt(short, long)]
         primary: Option<String>,
+        /// The command will exit immediatly after asking for a dump
+        #[structopt(long)]
+        r#async: bool,
     },
     /// Update an index, by default use the index provided by `-i`.
     Update {
@@ -168,11 +189,17 @@ pub enum IndexesCommand {
         /// Primary key
         #[structopt(short, long)]
         primary: Option<String>,
+        /// The command will exit immediatly after asking for a dump
+        #[structopt(long)]
+        r#async: bool,
     },
     /// Delete an index, by default use the index provided by `-i`.
     Delete {
         /// The index you want to delete.
         #[structopt(name = "idx")]
         index: Option<String>,
+        /// The command will exit immediatly after asking for a dump
+        #[structopt(long)]
+        r#async: bool,
     },
 }
